@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Settings
- * @version    $Id: 130.webserver.php 852 2010-04-28 09:34:50Z d00p $
+ * @version    $Id: 130.webserver.php 928 2010-05-11 08:50:35Z d00p $
  */
 
 return array(
@@ -152,6 +152,24 @@ return array(
 					'default' => '',
 					'save_method' => 'storeSettingField',
 					),
+				'customredirect_enabled' => array(
+					'label' => $lng['serversettings']['customredirect_enabled'],
+					'settinggroup' => 'customredirect',
+					'varname' => 'enabled',
+					'type' => 'bool',
+					'default' => false,
+					'save_method' => 'storeSettingField',
+					),
+				'customredirect_default' => array(
+					'label' => $lng['serversettings']['customredirect_default'],
+					'settinggroup' => 'customredirect',
+					'varname' => 'default',
+					'type' => 'option',
+					'default' => '1',
+					'option_mode' => 'one',
+					'option_options_method' => 'getRedirectCodes',
+					'save_method' => 'storeSettingField',
+					),					
 				),
 			),
 		'ssl' => array(
