@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Settings
- * @version    $Id: 160.nameserver.php 829 2010-04-20 06:22:11Z d00p $
+ * @version    $Id: 160.nameserver.php 1006 2010-05-27 20:34:49Z d00p $
  */
 
 return array(
@@ -65,7 +65,7 @@ return array(
 					'varname' => 'defaultttl',
 					'type' => 'int',
 					'default' => 604800, /* 1 week */
-					'int_min' => 86400, /* 1 day */
+					'int_min' => 3600, /* 1 hour */
 					'int_max' => 2147483647, /* integer max */
 					'save_method' => 'storeSettingField',
 					),
