@@ -12,7 +12,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Install
- * @version    $Id: update_0.9.inc.php 948 2010-05-17 10:23:25Z d00p $
+ * @version    $Id: update_0.9.inc.php 1035 2010-05-31 09:01:29Z d00p $
  */
 
 if(isFroxlorVersion('0.9-r0'))
@@ -768,4 +768,11 @@ if(isFroxlorVersion('0.9.7-svn3'))
 	updateToVersion('0.9.7');
 }
 
+if(isFroxlorVersion('0.9.7'))
+{
+	showUpdateStep("Updating from 0.9.7 to 0.9.8 final");
+	lastStepStatus(0);
+	updateToVersion('0.9.8');
+}
+
 ?>
