@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Configfiles
- * @version    $Id: gentoo.inc.php 860 2010-04-30 16:38:02Z Dessa $
+ * @version    $Id: gentoo.inc.php 954 2010-05-19 06:07:02Z d00p $
  */
 
 return Array(
@@ -320,10 +320,8 @@ milter_default_action = accept" >> /etc/postfix/main.cf'
 						'label' => 'Awstats',
 						'commands' => Array(
 							'emerge awstats',
-							'awstats_configure.pl'
-						),
-						'files' => Array(
-							'etc_awstats.model.conf' => makeCorrectFile($settings['system']['awstats_conf'].'/awstats.model.conf')
+							'awstats_configure.pl',
+							'sed -i.bak \'s/^DirData/# DirData/\''.makeCorrectFile($settings['system']['awstats_conf'].'/awstats.model.conf')
 						),
 					),
 					'libnss' => Array(
