@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Configfiles
- * @version    $Id: suse10.inc.php 844 2010-04-26 06:32:40Z d00p $
+ * @version    $Id: suse10.inc.php 954 2010-05-19 06:07:02Z d00p $
  */
 
 return Array(
@@ -154,10 +154,8 @@ return Array(
 						'label' => 'Awstats',
 						'commands' => Array(
 							'awstats_configure.pl',
-							makeCorrectFile($settings['system']['awstats_conf'].'/awstats.conf').' '.makeCorrectFile($settings['system']['awstats_conf'].'/awstats.model.conf')
-						),
-						'files' => Array(
-							'etc_awstats.model.conf' => makeCorrectFile($settings['system']['awstats_conf'].'/awstats.model.conf')
+							makeCorrectFile($settings['system']['awstats_conf'].'/awstats.conf').' '.makeCorrectFile($settings['system']['awstats_conf'].'/awstats.model.conf'),
+							'sed -i.bak \'s/^DirData/# DirData/\''.makeCorrectFile($settings['system']['awstats_conf'].'/awstats.model.conf')
 						)
 					)
 				)
