@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_init.php 701 2010-03-30 09:18:22Z d00p $
+ * @version    $Id: cron_init.php 773 2010-04-12 05:49:16Z d00p $
  */
 
 if(@php_sapi_name() != 'cli'
@@ -75,7 +75,7 @@ while($fName = readdir($lockDirHandle))
 		// Check if cron is running or has died.
 
 		$check_pid = substr(strstr($fName, "-"), 1);
-		system("kill -CHLD " . $check_pid . " 1> /dev/null 2> /dev/null", $check_pid_return);
+		system("kill -CHLD " . (int)$check_pid . " 1> /dev/null 2> /dev/null", $check_pid_return);
 
 		if($check_pid_return == 1)
 		{
