@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    System
- * @version    $Id: init.php 779 2010-04-13 05:41:09Z d00p $
+ * @version    $Id: init.php 870 2010-05-03 11:47:06Z d00p $
  */
 
 // prevent Froxlor pages from being cached
@@ -158,7 +158,15 @@ $settings = loadSettings($settings_data, $db);
 if(!isset($settings['admin']['froxlor_graphic'])
 	|| $settings['admin']['froxlor_graphic'] == ''
 ) {
-	$settings['admin']['froxlor_graphic'] = ($settings['admin']['syscp_graphic'] != '') ? $settings['admin']['syscp_graphic'] : 'images/header.gif';
+	if(isset($settings['admin']['syscp_graphic']) 
+		&& $settings['admin']['syscp_graphic'] != ''
+	){
+		$settings['admin']['froxlor_graphic'] = $settings['admin']['syscp_graphic'];
+	}
+	else
+	{
+		$settings['admin']['froxlor_graphic'] = 'images/header.gif';
+	}
 }
 
 /**
@@ -414,12 +422,14 @@ if($page == '')
 /**
  * Initialize the mailingsystem
  */
-
 $mail = new PHPMailer();
-// set return-to address and custom sender-name, see #76
-$mail->SetFrom($settings['panel']['adminmail'], $settings['panel']['adminmail_defname']);
-if ($settings['panel']['adminmail_return'] != '') {
-	$mail->AddReplyTo($settings['panel']['adminmail_return'], $settings['panel']['adminmail_defname']);
+if(PHPMailer::ValidateAddress($settings['panel']['adminmail']) !== false)
+{	
+	// set return-to address and custom sender-name, see #76
+	$mail->SetFrom($settings['panel']['adminmail'], $settings['panel']['adminmail_defname']);
+	if ($settings['panel']['adminmail_return'] != '') {
+		$mail->AddReplyTo($settings['panel']['adminmail_return'], $settings['panel']['adminmail_defname']);
+	}
 }
  
 ?>
