@@ -14,7 +14,7 @@
  * @author     Froxlor Team <team@froxlor.org>
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Language
- * @version    $Id: english.lng.php 940 2010-05-17 08:26:55Z d00p $
+ * @version    $Id: english.lng.php 1027 2010-05-31 06:04:51Z d00p $
  */
 
 /**
@@ -1420,4 +1420,7 @@ $lng['redirect_desc']['rc_found'] = 'found';
 $lng['redirect_desc']['rc_seeother'] = 'see other';
 $lng['redirect_desc']['rc_tempred'] = 'temporary redirect';
 
+// ADDED UN FROXLOR 0.9.8
+$lng['error']['exception'] = '%s';
+
 ?>
