@@ -13,7 +13,7 @@
  * @author     Michal Gozdzik <michal@gozdzik.com> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Language
- * @version    $Id: polish.lng.php 867 2010-05-02 20:32:12Z Dessa $
+ * @version    $Id: polish.lng.php 946 2010-05-17 09:14:30Z Dessa $
  */
 
 /**
@@ -344,12 +344,12 @@ $lng['serversettings']['ipaddress']['title'] = 'Adres IP';
 $lng['serversettings']['ipaddress']['description'] = 'Jaki jest adres IP tego serwera?';
 $lng['serversettings']['hostname']['title'] = 'Hostname';
 $lng['serversettings']['hostname']['description'] = 'Jaki jest Hostname serwera?';
-$lng['serversettings']['apachereload_command']['title'] = 'Apache reload command';
-$lng['serversettings']['apachereload_command']['description'] = 'What\'s the apache command to reload apache configfiles?';
-$lng['serversettings']['bindconf_directory']['title'] = 'Bind config directory';
-$lng['serversettings']['bindconf_directory']['description'] = 'Where should bind configfiles be saved?';
-$lng['serversettings']['bindreload_command']['title'] = 'Bind reload command';
-$lng['serversettings']['bindreload_command']['description'] = 'What\'s the bind command to reload bind configfiles?';
+$lng['serversettings']['apachereload_command']['title'] = 'Komenda przeadowania Apache';
+$lng['serversettings']['apachereload_command']['description'] = 'Jaka jest komenda, do przeadowania plikw konfiguracyjnych Apacha?';
+$lng['serversettings']['bindconf_directory']['title'] = 'Katalog z konfiguracj Bunda';
+$lng['serversettings']['bindconf_directory']['description'] = 'Gdzie maja by zapisywane pliki konfiguracyjne dla Binda?';
+$lng['serversettings']['bindreload_command']['title'] = 'Komenda przeadowania Binda';
+$lng['serversettings']['bindreload_command']['description'] = 'Jaka jest komenda, do przeadowania plikw konfiguracyjnych Binda?';
 $lng['serversettings']['binddefaultzone']['title'] = 'Bind default zone';
 $lng['serversettings']['binddefaultzone']['description'] = 'What\'s the name of the default zone?';
 $lng['serversettings']['vmail_uid']['title'] = 'Mails-UID';
@@ -367,7 +367,7 @@ $lng['serversettings']['webmail_url']['description'] = 'Jaki jest adres URL do W
 $lng['serversettings']['webftp_url']['title'] = 'URL do WebFTPa';
 $lng['serversettings']['webftp_url']['description'] = 'Jaki jest adres URL do WebFTPa? (Musi si&#281 rozpoczyna&#263 do http(s)://)';
 $lng['serversettings']['language']['description'] = 'Jaki jest standardowy j&#281zyk serwera?';
-$lng['serversettings']['maxloginattempts']['title'] = 'Max Login Attempts';
+$lng['serversettings']['maxloginattempts']['title'] = 'Maksymalna ilo prb logowania';
 $lng['serversettings']['maxloginattempts']['description'] = 'Maximum login attempts after which the account gets deactivated.';
 $lng['serversettings']['deactivatetime']['title'] = 'Czas zablokowania';
 $lng['serversettings']['deactivatetime']['description'] = 'Czas (sek.) zablokowania dost&#281pu do konta po nieudanym logowaniu.';
@@ -710,7 +710,7 @@ $lng['serversettings']['mod_fcgid']['tmpdir'] = 'Katalog plikw tymczasowych';
 $lng['serversettings']['ticket']['reset_cycle'] = 'Okresowe reset licznika u&#380ycia zg&#322osze&#324 pomocy technicznej';
 $lng['serversettings']['ticket']['reset_cycle_desc'] = 'Resetowanie zg&#322osze&#324 pomocy technicznej powoduje ustawienie licznika na warto&#347&#263 0 przy ka&#380dym cyklu';
 $lng['admin']['tickets']['daily'] = 'Dziennie';
-$lng['admin']['tickets']['weekly'] = 'Wygodniowo';
+$lng['admin']['tickets']['weekly'] = 'Tygodniowo';
 $lng['admin']['tickets']['monthly'] = 'Miesi&#281cznie';
 $lng['admin']['tickets']['yearly'] = 'Rocznie';
 $lng['error']['ticketresetcycleiswrong'] = 'The cycle for ticket-resets has to be "daily", "weekly", "monthly" or "yearly".';
@@ -1349,7 +1349,7 @@ $lng['serversettings']['stdsubdomainhost']['description'] = 'What hostname shoul
 // ADDED IN FROXLOR 0.9.4-svn1
 $lng['ftp']['account_edit'] = 'Edytuj konto ftp';
 $lng['ftp']['editpassdescription'] = 'Ustal nowe has&#322o lub zostaw puste by nie zmienia&#263.';
-$lng['mysql']['sendinfomail'] = 'Send data via email to me';
+$lng['customer']['sendinfomail'] = 'Send data via email to me';
 $lng['customer']['mysql_add']['infomail_subject'] = '[Froxlor] Nowa baza danych utworzona';
 $lng['customer']['mysql_add']['infomail_body']['pma'] = "\nMasz dost&#281p do Twojej bazy danych uzywaj&#261c phpMyAdmina pod adresem {URI}\n";
 $lng['customer']['mysql_add']['infomail_body']['main'] = "Witaj {CUST_NAME},\n\nw&#322a&#347nie doda&#322e&#347 now&#261 baz&#281 danych. Przesy&#322amy dane uruchomieniowe:\n\nBaza danych: {DB_NAME}\nHas&#322o: {DB_PASS}\nOpis: {DB_DESC}\n{PMA_URI}\nZ powa&#380aniem, Froxlor";
@@ -1376,4 +1376,18 @@ $lng['serversettings']['defaultwebsrverrhandler_err404'] = 'Plik/URL dla b&#322&
 $lng['serversettings']['defaultwebsrverrhandler_err500']['title'] = 'Plik/URL dla b&#322&#281du 500';
 $lng['serversettings']['defaultwebsrverrhandler_err500']['description'] = '<div style="color:red">'.$lng['panel']['not_supported'].'lighttpd</div>';
 
+// ADDED IN FROXLOR 0.9.6-svn4
+$lng['serversettings']['ticket']['default_priority'] = 'Standardowy priorytet dla zgosze pomocy technicznej';
+
+// ADDED IN FROXLOR 0.9.6-svn5
+$lng['serversettings']['mod_fcgid']['defaultini'] = 'Default PHP configuration for new domains';
+
+// ADDED IN FROXLOR 0.9.6-svn6
+$lng['admin']['ftpserver'] = 'Serwer FTP';
+$lng['admin']['ftpserversettings'] = 'Ustawienia Serwera FTP';
+$lng['serversettings']['ftpserver']['desc'] = 'Jeli pureftpd jest zaznaczone, plik .ftpquota z quotami uytkownika bdzie tworzony i aktualizowany codziennie';
+
+// CHANGED IN FROXLOR 0.9.6-svn6
+$lng['serversettings']['ftpprefix']['description'] = 'Which prefix should ftp accounts have?<br/><b>If you change this you also have to change the Quota SQL Query in your FTP Server config file in case you use it!</b> ';
+
 ?>
\ No newline at end of file
