@@ -14,7 +14,7 @@
  * @author     Froxlor Team <team@froxlor.org>
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Language
- * @version    $Id: swedish.lng.php 105 2010-01-25 09:11:52Z EleRas $
+ * @version    $Id: swedish.lng.php 759 2010-04-09 19:24:17Z EleRas $
  */
 
 /**
@@ -387,7 +387,6 @@ $lng['mysql']['description'] = 'Hr ndras eller skapas MySQL-Databaser.<br />ndri
  * ADDED BETWEEN 1.2.12 and 1.2.13
  */
 
-$lng['admin']['cronlastrun'] = 'Konfigurerinsfilerna skapades sist';
 $lng['serversettings']['paging']['title'] = 'Antal rader per sida';
 $lng['serversettings']['paging']['description'] = 'Hur mnga rader skall det vara p en sida? (0 = Stng av sidbrytning)';
 $lng['error']['ipstillhasdomains'] = 'IP/Port kombinationen som du vill radera har fortfarande domner anslutna till sig, Flytta dessa till ngon annan IP/Port kombination innan du raderar denna IP/Port kombination.';
@@ -529,7 +528,6 @@ $lng['admin']['configfiles']['etc'] = 'Others (System)';
 $lng['admin']['configfiles']['choosedistribution'] = '-- Choose a distribution --';
 $lng['admin']['configfiles']['chooseservice'] = '-- Choose a service --';
 $lng['admin']['configfiles']['choosedaemon'] = '-- Choose a daemon --';
-$lng['admin']['trafficlastrun'] = 'Senaste trafikberkningen gjordes';
 
 // ADDED IN 1.2.16-svn10
 
