@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_tasks.inc.http.10.apache.php 930 2010-05-12 06:52:11Z d00p $
+ * @version    $Id: cron_tasks.inc.http.10.apache.php 1024 2010-05-29 18:53:16Z EleRas $
  */
 
 if(@php_sapi_name() != 'cli'
@@ -67,7 +67,14 @@ class apache
 	 */
 	private function _createStandardDirectoryEntry()
 	{
-		$vhosts_filename = makeCorrectFile($this->settings['system']['apacheconf_vhost'] . '/05_froxlor_dirfix_nofcgid.conf');
+		$vhosts_folder = '';
+		if(is_dir($this->settings['system']['apacheconf_vhost']))
+		{
+			$vhosts_folder = makeCorrectDir($this->settings['system']['apacheconf_vhost']);
+		} else {
+			$vhosts_folder = makeCorrectDir(dirname($this->settings['system']['apacheconf_vhost']));
+		}
+		$vhosts_filename = makeCorrectFile($vhosts_folder . '/05_froxlor_dirfix_nofcgid.conf');
 
 		if($this->settings['system']['mod_fcgid'] == '1')
 		{
@@ -104,7 +111,15 @@ class apache
 			|| $this->settings['defaultwebsrverrhandler']['err404'] != ''
 			|| $this->settings['defaultwebsrverrhandler']['err500'] != '')
 		) {
-			$vhosts_filename = makeCorrectFile($this->settings['system']['apacheconf_vhost'] . '/05_froxlor_default_errorhandler.conf');
+			$vhosts_folder = '';
+			if(is_dir($this->settings['system']['apacheconf_vhost']))
+			{
+				$vhosts_folder = makeCorrectDir($this->settings['system']['apacheconf_vhost']);
+			} else {
+				$vhosts_folder = makeCorrectDir(dirname($this->settings['system']['apacheconf_vhost']));
+			}
+			
+			$vhosts_filename = makeCorrectFile($vhosts_folder . '/05_froxlor_default_errorhandler.conf');
 
 			if(!isset($this->virtualhosts_data[$vhosts_filename]))
 			{
@@ -177,7 +192,7 @@ class apache
 				/**
 				 * add 'real'-vhost content here, like doc-root :)
 				 */
-				$mypath = makeCorrectDir(dirname(dirname(dirname(__FILE__))));
+				$mypath = makeCorrectDir(dirname(dirname(dirname(dirname(__FILE__)))));
 				$this->virtualhosts_data[$vhosts_filename].= 'DocumentRoot "'.$mypath.'"'."\n";
 				
 				if($row_ipsandports['vhostcontainer_servername_statement'] == '1')
@@ -278,8 +293,13 @@ class apache
 				{
 					$_phpappendopenbasedir = appendOpenBasedirPath($domain['documentroot'], true);
 				}
-				$_phpappendopenbasedir .= appendOpenBasedirPath($this->settings['system']['phpappendopenbasedir']);
 				
+				$_custom_openbasedir = explode(':', $this->settings['system']['phpappendopenbasedir']);
+				foreach($_custom_openbasedir as $cobd)
+				{
+					$_phpappendopenbasedir .= appendOpenBasedirPath($cobd);
+				}
+
 				$php_options_text.= '  php_admin_value open_basedir "' . $_phpappendopenbasedir . '"'."\n";
 			}
 
