@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_tasks.inc.http.20.lighttpd.php 848 2010-04-28 07:04:01Z d00p $
+ * @version    $Id: cron_tasks.inc.http.20.lighttpd.php 957 2010-05-19 12:29:32Z EleRas $
  */
 
 /*
@@ -107,7 +107,7 @@ class lighttpd
 				$this->lighttpd_data[$vhost_filename].= '# Froxlor default vhost' . "\n";
 				$this->lighttpd_data[$vhost_filename].= '$HTTP["host"] =~ "^(?:www\.|)' . $myhost . '$" {' . "\n";
 
-				$mypath = makeCorrectDir(dirname(dirname(dirname(__FILE__))));
+				$mypath = makeCorrectDir(dirname(dirname(dirname(dirname(__FILE__)))));
 				$this->lighttpd_data[$vhost_filename].= '  server.document-root = "'.$mypath.'"'."\n";
 
 				/**
