@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_traffic.inc.functions.php 795 2010-04-14 08:26:13Z d00p $
+ * @version    $Id: cron_traffic.inc.functions.php 926 2010-05-10 12:18:12Z d00p $
  */
 
 function awstatsDoSingleDomain($domain, $outputdir)
@@ -36,6 +36,7 @@ function awstatsDoSingleDomain($domain, $outputdir)
 		 * check for correct path of awstats_buildstaticpages.pl
 		 */
 		$awbsp = makeCorrectFile($settings['system']['awstats_path'].'/awstats_buildstaticpages.pl');
+		$awprog = makeCorrectFile($settings['system']['awstats_path'].'/awstats.pl');
 		
 		if (!file_exists($awbsp)) {
 			echo "WANRING: Necessary awstats_buildstaticpages.pl script could not be found, no traffic is being calculated and no stats are generated. Please check your AWStats-Path setting";
@@ -44,7 +45,7 @@ function awstatsDoSingleDomain($domain, $outputdir)
 		}
 
 		$cronlog->logAction(CRON_ACTION, LOG_INFO, "Running awstats_buildstaticpages.pl for domain '".$domain."' (Output: '".$outputdir."')");
-		safe_exec($awbsp.' -update -config=' . $domain . ' -dir='.escapeshellarg($outputdir));
+		safe_exec($awbsp.' -awstatsprog='.escapeshellarg($awprog).' -update -config=' . $domain . ' -dir='.escapeshellarg($outputdir));
 		
 		/**
 		 * index file is saved like 'awstats.[domain].html',
